Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4480)

Unified Diff: chrome/browser/chromeos/login/signin/merge_session_throttling_utils.h

Issue 1910693002: Avoid the long merge session throttle interstitial page for NTP on Chrome OS (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: treib's comments Created 4 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/login/signin/merge_session_throttling_utils.h
diff --git a/chrome/browser/chromeos/login/signin/merge_session_throttling_utils.h b/chrome/browser/chromeos/login/signin/merge_session_throttling_utils.h
index 2abe52aac1757bcaa74dbb4c05c663f0cddb3c9e..f9dc6134d1baf5f1b192fa7e658934d8aff314d9 100644
--- a/chrome/browser/chromeos/login/signin/merge_session_throttling_utils.h
+++ b/chrome/browser/chromeos/login/signin/merge_session_throttling_utils.h
@@ -33,8 +33,9 @@ bool AreAllSessionMergedAlready();
void BlockProfile(Profile* profile);
void UnblockProfile(Profile* profile);
-// Whether requests from |web_contents| should currently be delayed. This
-// should be called on the UI thread.
+// Whether requests from |web_contents| or |profile| should currently be
+// delayed. This should be called on the UI thread.
+bool ShouldDelayRequest(Profile* profile);
bool ShouldDelayRequest(content::WebContents* web_contents);
// True if the load of |url| should be delayed. The function is safe to be
« no previous file with comments | « no previous file | chrome/browser/chromeos/login/signin/merge_session_throttling_utils.cc » ('j') | chrome/browser/search/search.cc » ('J')

Powered by Google App Engine
This is Rietveld 408576698